"""
Caracal Core - Pre-Execution Authority Enforcement System for AI Agents

Caracal Core provides execution authority, mandate management, delegation,
policy enforcement, and audit capabilities for AI agents.
"""

from caracal._version import __version__

__all__ = ["__version__"]
